Name:           jackson-databind
Version:        2.11.4
%define subrel 1
Release:        %mkrel 2
Group:          Development/Java
Summary:        General data-binding package for Jackson (2.x)
License:        ASL 2.0 and LGPLv2+

URL:            https://github.com/FasterXML/jackson-databind
Source0:        %{url}/archive/%{name}-%{version}.tar.gz
Patch0:         CVE-2020-36518.patch
Patch1:         CVE-2022-42003.patch
Patch2:         CVE-2022-42004.patch

BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-annotations) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-core) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson:jackson-base:pom:) >= %{version}
BuildRequires:  mvn(com.google.code.maven-replacer-plugin:replacer)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.mockito:mockito-core)

BuildArch:      noarch

%description
The general-purpose data-binding functionality and tree-model for Jackson Data
Processor. It builds on core streaming parser/generator package, and uses
Jackson Annotations for configuration.

%package javadoc
Summary: Javadoc for %{name}

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}
%autopatch -p1

# Remove plugins unnecessary for RPM builds
%pom_remove_plugin ":maven-enforcer-plugin"
%pom_remove_plugin "org.jacoco:jacoco-maven-plugin"
%pom_remove_plugin "org.moditect:moditect-maven-plugin"

cp -p src/main/resources/META-INF/NOTICE .
sed -i 's/\r//' LICENSE NOTICE

# unavailable test deps
%pom_remove_dep javax.measure:jsr-275
rm src/test/java/com/fasterxml/jackson/databind/introspect/NoClassDefFoundWorkaroundTest.java
%pom_xpath_remove pom:classpathDependencyExcludes

# TestTypeFactoryWithClassLoader fails to compile
# - it's the only test that uses powermock, so drop the powermock dependencies
# - mockito is only transitively pulled in by powermock, so add it back
%pom_remove_dep org.powermock:
%pom_add_dep org.mockito:mockito-core::test
rm src/test/java/com/fasterxml/jackson/databind/type/TestTypeFactoryWithClassLoader.java

# Off test that require connection with the web
rm src/test/java/com/fasterxml/jackson/databind/ser/jdk/JDKTypeSerializationTest.java \
 src/test/java/com/fasterxml/jackson/databind/deser/jdk/JDKStringLikeTypesTest.java \
 src/test/java/com/fasterxml/jackson/databind/TestJDKSerialization.java

%mvn_file : %{name}

%build
%mvn_build -- -Dmaven.test.failure.ignore=true

%install
%mvn_install

%files -f .mfiles
%doc README.md release-notes/*
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE



%changelog
* Fri Mar 15 2024 ns80 <ns80> 2.11.4-2.1.mga9
+ Revision: 2049985
- port patches from Debian for CVE-2020-36518 and CVE-2022-4200[34] (mga#30368)

* Sat Mar 26 2022 umeabot <umeabot> 2.11.4-2.mga9
+ Revision: 1827722
- Mageia 9 Mass Rebuild

* Mon Mar 01 2021 daviddavid <daviddavid> 2.11.4-1.mga9
+ Revision: 1694870
- Update to version 2.11.4

* Wed Oct 21 2020 daviddavid <daviddavid> 2.11.3-1.mga8
+ Revision: 1637880
- Update to version 2.11.3

* Sat Sep 05 2020 daviddavid <daviddavid> 2.11.2-1.mga8
+ Revision: 1622427
- Update to version 2.11.2
- Drop useless powermock build dependency

* Sun Feb 16 2020 umeabot <umeabot> 2.10.0-2.mga8
+ Revision: 1536241
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 2.10.0-1.mga8
+ Revision: 1453499
- Update to version 2.10.0
- Fixes: CVE-2019-14540
- Fixes: CVE-2019-16335
- Fixes: CVE-2019-16942
- Fixes: CVE-2019-16943

* Thu Feb 07 2019 daviddavid <daviddavid> 2.9.8-1.mga7
+ Revision: 1363848
- Update to latest upstream release 2.9.8, fixes CVE-2018-14718 CVE-2018-147189
  CVE-2018-1936[0,1,2] CVE-2018-1202[2,3] CVE-2018-1472[0,1]

* Mon Nov 26 2018 wally <wally> 2.9.4-1.mga7
+ Revision: 1335301
- new version 2.9.4 (sync with Fedora)

* Thu Sep 20 2018 umeabot <umeabot> 2.7.6-5.mga7
+ Revision: 1278891
- Mageia 7 Mass Rebuild

* Sat Feb 17 2018 daviddavid <daviddavid> 2.7.6-4.mga7
+ Revision: 1202110
- add 3 fedora patches to fix new security issues CVE-2017-17485 and CVE-2018-5968 (mga#22569)

* Sat Nov 04 2017 daviddavid <daviddavid> 2.7.6-3.mga7
+ Revision: 1175767
- add patch to fix CVE-2017-15095 (mga#21978)

* Tue Aug 01 2017 daviddavid <daviddavid> 2.7.6-2.mga7
+ Revision: 1133448
- Backport a patch to fix CVE-2017-7525 (mga#21428)

* Fri May 12 2017 neoclust <neoclust> 2.7.6-1.mga6
+ Revision: 1100585
- New version 2.7.6

* Wed Mar 02 2016 neoclust <neoclust> 2.6.3-3.mga6
+ Revision: 981891
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 2.6.3-2.mga6
+ Revision: 976494
- First rebuild of the java stack
- sync package jackson-databind with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Dec 25 2014 pterjan <pterjan> 2.4.3-4.mga5
+ Revision: 805701
- Clean rebuild
- Restore
- 2.4.3
- Sync with fedora
+ sander85 <sander85>
- Depends on broken java stack
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps

* Tue Oct 22 2013 umeabot <umeabot> 2.2.2-4.mga4
+ Revision: 541324
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 dmorgan <dmorgan> 2.2.2-3.mga4
+ Revision: 495504
- imported package jackson-databind


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jul 22 2013 gil cattaneo <puntogil@libero.it> 2.2.2-2
- review fixes

* Tue Jul 16 2013 gil cattaneo <puntogil@libero.it> 2.2.2-1
- 2.2.2
- renamed jackson-databind

* Tue May 07 2013 gil cattaneo <puntogil@libero.it> 2.2.1-1
- 2.2.1

* Wed Oct 24 2012 gil cattaneo <puntogil@libero.it> 2.1.0-1
- update to 2.1.0
- renamed jackson2-databind

* Thu Sep 13 2012 gil cattaneo <puntogil@libero.it> 2.0.6-1
- initial rpm
